summaryrefslogtreecommitdiffhomepage
path: root/Kernel/Sources/SMPManager.cxx
diff options
context:
space:
mode:
authorAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:35 +0200
committerAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:49 +0200
commit375d0210dcb2070a12d916523f4a1dafff28360c (patch)
treed0c217f529b8069ea659778c2ee9ca20aeba33a4 /Kernel/Sources/SMPManager.cxx
parentf1d3744829a661d1600c2f3bbdbdf679ee0bd0e1 (diff)
MHR-36: Change namespace name, got out of the codename stage.
Signed-off-by: Amlal EL Mahrouss <amlalelmahrouss@icloud.com>
Diffstat (limited to 'Kernel/Sources/SMPManager.cxx')
-rw-r--r--Kernel/Sources/SMPManager.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Kernel/Sources/SMPManager.cxx b/Kernel/Sources/SMPManager.cxx
index f00fbee1..8b0aca9b 100644
--- a/Kernel/Sources/SMPManager.cxx
+++ b/Kernel/Sources/SMPManager.cxx
@@ -11,10 +11,10 @@
///! BUGS: 0
///! @file SMPManager.cxx
///! @brief This file handles multi processing in NewOS.
///! @brief Multi processing is needed for multi-tasking operations.
-namespace NewOS
+namespace Kernel
{
///! A HardwareThread class takes care of it's owned hardware thread.
///! It has a stack for it's core.
@@ -244,4 +244,4 @@ namespace NewOS
{
return fThreadList.Count();
}
-} // namespace NewOS
+} // namespace Kernel
@@ -11,10 +11,10 @@
///! BUGS: 0
///! @file SMPManager.cxx
-///! @brief This file handles multi processing in NewOS.
+///! @brief This file handles multi processing in Kernel.
///! @brief Multi processing is needed for multi-tasking operations.